Class: Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicle
- Inherits:
-
Object
- Object
- Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicle
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb
Overview
The DeliveryVehicle message. A delivery vehicle transports shipments from a
depot to a delivery location, and from a pickup location to the depot. In
some cases, delivery vehicles also transport shipments directly from the
pickup location to the delivery location.
Note: gRPC and REST APIs use different field naming conventions. For example,
the DeliveryVehicle.current_route_segment field in the gRPC API and the
DeliveryVehicle.currentRouteSegment field in the REST API refer to the same
field.
Defined Under Namespace
Modules: DeliveryVehicleType
Instance Attribute Summary collapse
-
#attributes ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleAttribute>
A list of custom Delivery Vehicle attributes.
-
#current_route_segment ⇒ ::String
The encoded polyline specifying the route that the navigation recommends taking to the next waypoint.
-
#current_route_segment_end_point ⇒ ::Google::Type::LatLng
The location where the
current_route_segmentends. -
#last_location ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleLocation
The last reported location of the Delivery Vehicle.
-
#name ⇒ ::String
The unique name of this Delivery Vehicle.
-
#navigation_status ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleNavigationStatus
The Delivery Vehicle's navigation status.
-
#past_locations ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleLocation>
Input only.
-
#remaining_distance_meters ⇒ ::Google::Protobuf::Int32Value
The remaining driving distance for the
current_route_segment. -
#remaining_duration ⇒ ::Google::Protobuf::Duration
The remaining driving time for the
current_route_segment. -
#remaining_vehicle_journey_segments ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::VehicleJourneySegment>
The journey segments assigned to this Delivery Vehicle, starting from the Vehicle's most recently reported location.
-
#type ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicle::DeliveryVehicleType
The type of this delivery vehicle.
Instance Attribute Details
#attributes ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleAttribute>
Returns A list of custom Delivery Vehicle attributes. A Delivery Vehicle can have at most 100 attributes, and each attribute must have a unique key.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#current_route_segment ⇒ ::String
Returns The encoded polyline specifying the route that the navigation recommends
taking to the next waypoint. Your driver app updates this when a
stop is reached or passed, and when the navigation reroutes. These
LatLngs are returned in
Task.journey_sharing_info.remaining_vehicle_journey_segments[0].path
(gRPC) or Task.journeySharingInfo.remainingVehicleJourneySegments[0].path
(REST) for all active Tasks assigned to the Vehicle.
There are a few cases where this field might not be used to populate
Task.journey_sharing_info.remaining_vehicle_journey_segments[0].path
(gRPC) or Task.journeySharingInfo.remainingVehicleJourneySegments[0].path
(REST):
The endpoint of the
current_route_segmentdoes not matchDeliveryVehicle.remaining_vehicle_journey_segments[0].stop(gRPC) orDeliveryVehicle.remainingVehicleJourneySegments[0].stop(REST).The driver app has not updated its location recently, so the last updated value for this field might be stale.
The driver app has recently updated its location, but the
current_route_segmentis stale, and points to a previous vehicle stop.
In these cases, Fleet Engine populates this field with a route from the most recently passed VehicleStop to the upcoming VehicleStop to ensure that the consumer of this field has the best available information on the current path of the Delivery Vehicle.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#current_route_segment_end_point ⇒ ::Google::Type::LatLng
Returns The location where the current_route_segment ends. This is not currently
populated by the driver app, but you can supply it on
UpdateDeliveryVehicle calls. It is either the LatLng from the upcoming
vehicle stop, or the last LatLng of the current_route_segment. Fleet
Engine will then do its best to interpolate to an actual VehicleStop.
This field is ignored in UpdateDeliveryVehicle calls if the
current_route_segment field is empty.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#last_location ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleLocation
Returns The last reported location of the Delivery Vehicle.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#name ⇒ ::String
Returns The unique name of this Delivery Vehicle.
The format is providers/{provider}/deliveryVehicles/{vehicle}.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#navigation_status ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleNavigationStatus
Returns The Delivery Vehicle's navigation status.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#past_locations ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicleLocation>
Returns Input only. Locations where this Delivery Vehicle has been in the past that
haven't yet been reported to Fleet Engine. This is used in
UpdateDeliveryVehicleRequest to record locations which were previously
unable to be sent to the server. Typically this happens when the Delivery
Vehicle does not have internet connectivity.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#remaining_distance_meters ⇒ ::Google::Protobuf::Int32Value
Returns The remaining driving distance for the current_route_segment.
The Driver app typically provides this field, but there are some
circumstances in which Fleet Engine will override the value sent by the
app. For more information, see
DeliveryVehicle.current_route_segment.
This field is returned in
Task.remaining_vehicle_journey_segments[0].driving_distance_meters (gRPC)
or Task.remainingVehicleJourneySegments[0].drivingDistanceMeters (REST)
for all active Tasks assigned to the Delivery Vehicle.
Fleet Engine ignores this field in UpdateDeliveryVehicleRequest if the
current_route_segment field is empty.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#remaining_duration ⇒ ::Google::Protobuf::Duration
Returns The remaining driving time for the current_route_segment.
The Driver app typically provides this field, but there are some
circumstances in which Fleet Engine will override the value sent by the
app. For more information, see
DeliveryVehicle.current_route_segment.
This field is returned in
Task.remaining_vehicle_journey_segments[0].driving_duration (gRPC) or
Task.remainingVehicleJourneySegments[0].drivingDuration (REST) for all
active tasks assigned to the Delivery Vehicle.
Fleet Engine ignores this field in UpdateDeliveryVehicleRequest if the
current_route_segment field is empty.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#remaining_vehicle_journey_segments ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::VehicleJourneySegment>
Returns The journey segments assigned to this Delivery Vehicle, starting from the
Vehicle's most recently reported location. This field won't be populated
in the response of ListDeliveryVehicles.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |
#type ⇒ ::Google::Maps::FleetEngine::Delivery::V1::DeliveryVehicle::DeliveryVehicleType
Returns The type of this delivery vehicle. If unset, this will default to AUTO.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_vehicles.rb', line 130 class DeliveryVehicle include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of delivery vehicle. module DeliveryVehicleType # The value is unused. DELIVERY_VEHICLE_TYPE_UNSPECIFIED = 0 # An automobile. AUTO = 1 # A motorcycle, moped, or other two-wheeled vehicle TWO_WHEELER = 2 # Human-powered transport. BICYCLE = 3 # A human transporter, typically walking or running, traveling along # pedestrian pathways. PEDESTRIAN = 4 end end |