Class: Google::Maps::FleetEngine::Delivery::V1::ListTasksResponse
- Inherits:
-
Object
- Object
- Google::Maps::FleetEngine::Delivery::V1::ListTasksResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/maps/fleetengine/delivery/v1/delivery_api.rb
Overview
The ListTasks response that contains the set of Tasks that meet the filter
criteria in the ListTasksRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
Pass this token in the
ListTasksRequestto continue to list results. -
#tasks ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::Task>
The set of Tasks that meet the requested filtering criteria.
-
#total_size ⇒ ::Integer
The total number of Tasks that match the request criteria, across all pages.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns Pass this token in the ListTasksRequest to continue to list results.
If all results have been returned, then this field is either an empty
string, or it doesn't appear in the response.
371 372 373 374 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_api.rb', line 371 class ListTasksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tasks ⇒ ::Array<::Google::Maps::FleetEngine::Delivery::V1::Task>
Returns The set of Tasks that meet the requested filtering criteria. When no filter is specified, the request returns all tasks. A successful response can also be empty. An empty response indicates that no Tasks were found meeting the requested filter criteria.
371 372 373 374 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_api.rb', line 371 class ListTasksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#total_size ⇒ ::Integer
Returns The total number of Tasks that match the request criteria, across all pages.
371 372 373 374 |
# File 'proto_docs/google/maps/fleetengine/delivery/v1/delivery_api.rb', line 371 class ListTasksResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |