Class: Google::Maps::FleetEngine::Delivery::V1::TaskTrackingViewConfig::VisibilityOption

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb

Overview

The option message that defines when a data element should be visible to the end users.

Instance Attribute Summary collapse

Instance Attribute Details

#always::Boolean

Returns If set to true, this data element is always visible to the end users with no thresholds. This field cannot be set to false.

Note: The following fields are mutually exclusive: always, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, never. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    If set to true, this data element is always visible to the end users with no thresholds. This field cannot be set to false.

    Note: The following fields are mutually exclusive: always, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, never. If a field in that set is populated, all other fields in the set will automatically be cleared.



282
283
284
285
# File 'proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb', line 282

class VisibilityOption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#duration_until_estimated_arrival_time_threshold::Google::Protobuf::Duration

Returns This data element is visible to the end users if the ETA to the stop <= duration_until_estimated_arrival_time_threshold.

Note: The following fields are mutually exclusive: duration_until_estimated_arrival_time_threshold, remaining_stop_count_threshold, remaining_driving_distance_meters_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Duration)

    This data element is visible to the end users if the ETA to the stop <= duration_until_estimated_arrival_time_threshold.

    Note: The following fields are mutually exclusive: duration_until_estimated_arrival_time_threshold, remaining_stop_count_threshold, remaining_driving_distance_meters_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.



282
283
284
285
# File 'proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb', line 282

class VisibilityOption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#never::Boolean

Returns If set to true, this data element is always hidden from the end users with no thresholds. This field cannot be set to false.

Note: The following fields are mutually exclusive: never, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, always. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    If set to true, this data element is always hidden from the end users with no thresholds. This field cannot be set to false.

    Note: The following fields are mutually exclusive: never, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, always. If a field in that set is populated, all other fields in the set will automatically be cleared.



282
283
284
285
# File 'proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb', line 282

class VisibilityOption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#remaining_driving_distance_meters_threshold::Integer

Returns This data element is visible to the end users if the remaining driving distance in meters <= remaining_driving_distance_meters_threshold.

Note: The following fields are mutually exclusive: remaining_driving_distance_meters_threshold, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    This data element is visible to the end users if the remaining driving distance in meters <= remaining_driving_distance_meters_threshold.

    Note: The following fields are mutually exclusive: remaining_driving_distance_meters_threshold, remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.



282
283
284
285
# File 'proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb', line 282

class VisibilityOption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#remaining_stop_count_threshold::Integer

Returns This data element is visible to the end users if the remaining stop count <= remaining_stop_count_threshold.

Note: The following fields are mutually exclusive: remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    This data element is visible to the end users if the remaining stop count <= remaining_stop_count_threshold.

    Note: The following fields are mutually exclusive: remaining_stop_count_threshold, duration_until_estimated_arrival_time_threshold, remaining_driving_distance_meters_threshold, always, never. If a field in that set is populated, all other fields in the set will automatically be cleared.



282
283
284
285
# File 'proto_docs/google/maps/fleetengine/delivery/v1/tasks.rb', line 282

class VisibilityOption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end